@@ -35,6 +35,18 @@ FAILEDOPERATION_CRUNSUPPORTMETHOD = 'FailedOperation.CRUnsupportMethod'
 # 房间中没有设置混流模板。
 FAILEDOPERATION_MIXSESSIONNOTEXIST = 'FailedOperation.MixSessionNotExist'
 
+# 需要解锁所需能力位
+FAILEDOPERATION_NOTABILITY = 'FailedOperation.NotAbility'
+
+# 未开通RTMP
+FAILEDOPERATION_NOTRTMPFUNCTION = 'FailedOperation.NotRtmpFunction'
+
+# 查询任务失败
+FAILEDOPERATION_QUERYTASKINFOFAILED = 'FailedOperation.QueryTaskInfoFailed'
+
+# 请求过期。
+FAILEDOPERATION_REQUESTOUTDATED = 'FailedOperation.RequestOutdated'
+
 # 云API混流模板和SDK混流冲突。
 FAILEDOPERATION_REQUESTREJECTION = 'FailedOperation.RequestRejection'
 
@@ -47,9 +59,21 @@ FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 # 应用ID不存在。
 FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
 
+# AppId下没有此SdkAppId的资源
+FAILEDOPERATION_SDKAPPIDNOTUNDERAPPID = 'FailedOperation.SdkAppIdNotUnderAppId'
+
+# SdkAppId未开通页面录制能力，请检查。
+FAILEDOPERATION_SDKAPPIDNOTWEBRECORDABILITY = 'FailedOperation.SdkAppIdNotWebRecordAbility'
+
+# 任务已存在
+FAILEDOPERATION_TASKEXIST = 'FailedOperation.TaskExist'
+
 # 调用接口时任务已结束。
 FAILEDOPERATION_TASKFINISHED = 'FailedOperation.TaskFinished'
 
+# 任务不存在或已结束
+FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -71,6 +95,9 @@ INTERNALERROR_GETROOMFROMCACHEERROR = 'InternalError.GetRoomFromCacheError'
 # http请求解析失败。
 INTERNALERROR_HTTPPARASEFALIED = 'InternalError.HttpParaseFalied'
 
+# http请求解析失败。
+INTERNALERROR_HTTPPARSEFAILED = 'InternalError.HttpParseFailed'
+
 # 接口错误。
 INTERNALERROR_INTERFACEERR = 'InternalError.InterfaceErr'
 
@@ -107,6 +134,9 @@ INVALIDPARAMETER_ENCODEPARAMS = 'InvalidParameter.EncodeParams'
 # EndTs参数错误。
 INVALIDPARAMETER_ENDTS = 'InvalidParameter.EndTs'
 
+# invalid sdkAppId
+INVALIDPARAMETER_INVALIDSDKAPPID = 'InvalidParameter.InvalidSdkAppId'
+
 # 大画面居右显示参数错误。
 INVALIDPARAMETER_MAINVIDEORIGHTALIGN = 'InvalidParameter.MainVideoRightAlign'
 
@@ -179,6 +209,9 @@ INVALIDPARAMETER_STRROOMID = 'InvalidParameter.StrRoomId'
 # StreamId参数错误。
 INVALIDPARAMETER_STREAMID = 'InvalidParameter.StreamId'
 
+# TaskId 参数错误。
+INVALIDPARAMETER_TASKID = 'InvalidParameter.TaskId'
+
 # Url解析参数失败。
 INVALIDPARAMETER_URLPARAMSERROR = 'InvalidParameter.UrlParamsError'
 
@@ -191,6 +224,12 @@ INVALIDPARAMETER_USERIDS = 'InvalidParameter.UserIds'
 # 用户数超过6个。
 INVALIDPARAMETER_USERIDSMORETHANSIX = 'InvalidParameter.UserIdsMorethanSix'
 
+# UserSig过期或错误。
+INVALIDPARAMETER_USERSIG = 'InvalidParameter.UserSig'
+
+# UserSig 不是超级管理员。
+INVALIDPARAMETER_USERSIGNOTADMIN = 'InvalidParameter.UserSigNotAdmin'
+
 # 视频分辨率参数错误。
 INVALIDPARAMETER_VIDEORESOLUTION = 'InvalidParameter.VideoResolution'
 
